import 'package:json_annotation/json_annotation.dart';
import 'package:barcode_scanner/sdk_utils.dart';

part 'scanbot_sdk_models.g.dart';

/// Scanbot SDK initialization config parameters.
class ScanbotSdkConfig {
  /// Your license key for the Scanbot SDK.
  String? licenseKey;

  /// Optional logging flag. While it may be useful for development,
  /// consider switching logging OFF in production builds for security and performance reasons!
  bool? loggingEnabled;

  /// Optional custom storage base directory. Can be nil.
  String? storageBaseDirectory;

  ScanbotSdkConfig(
      {this.licenseKey, this.loggingEnabled, this.storageBaseDirectory});
}

/// Scanbot SDK license status.
@JsonSerializable(
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class SdkLicenseStatus {
  /// Indicates whether the current license key is valid or not.
  bool isLicenseValid;
  Status? status;
  @JsonKey(fromJson: dateFromString)
  DateTime? expirationDate;
  SdkLicenseStatus(this.isLicenseValid);

  factory SdkLicenseStatus.fromJson(Map<String, dynamic> json) =>
      _$SdkLicenseStatusFromJson(json);

  Map<String, dynamic> toJson() => _$SdkLicenseStatusToJson(this);
}

enum Status {
  StatusOkay,
  StatusTrial,
  StatusFailureNotSet,
  StatusFailureCorrupted,
  StatusFailureWrongOS,
  StatusFailureAppIDMismatch,
  StatusFailureExpired
}
